import java.awt.*;
import java.awt.image.*;
import java.io.*;
import javax.imageio.*;
import javax.swing.*;
import javax.swing.text.*;

/**
 * Eigenes Grafik-Panel
 * 
 * @author Toens
 * @version v0.1
 */
public class PointPanel extends JPanel {
    MyPoint[] pointArray;
    
    public PointPanel(MyPoint[] pointArray) {
        this.pointArray = pointArray;
    }

    // screencoordinate von koordinate k
    private int sc(int k) {
        return (k + 15) * 5;
    }
    
    
    /**
     * Kernstueck des JGrafikPanels: paintComponent ist eine Methode, die
     * eigentlich von der Oberklasse JPanel stammt (unser JGrafikPanel erbt
     * ja von der JPanel-Klasse). Hier wird die Methode ueberschrieben.
     * Wir sorgen hier naemlich dafuer, dass unsere eigenen Inhalte dort
     * hineingezeichnet werden. Die Methode wird immer dann vom Fenstersystem
     * (bzw. indirekt vom Windows-Betriebssystem) aufgerufen, wenn der Inhalt
     * neu gezeichnet werden soll.
     */
    public void paintComponent(Graphics g) {
        Graphics2D g2 = (Graphics2D)g;
        g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
            RenderingHints.VALUE_ANTIALIAS_ON);
        g2.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
            RenderingHints.VALUE_INTERPOLATION_BILINEAR);

        super.paintComponent(g); // Zur Sicherheit die urspruengliche Methoder der Oberklasse aufrufen

        Rectangle r = getBounds(null);
        int h = r.height; // Höhe
        int w = r.width;  // Breite

        g.setColor(Color.gray);
        g.fillRect(0,0,w,h);       // Hintergrund füllen

        // genauere Dokumentation der Methoden: siehe
        // https://docs.oracle.com/javase/7/docs/api/java/awt/Graphics.html
        g.setColor(Color.black);
        g.fillOval(sc(0)-2 , sc(0)-2 , 4,4 );
        
        Point p = pointArray[0];
        g.drawLine(sc(0), sc(0), sc(p.x), sc(p.y));
        for(int i = 0; i < (pointArray.length-1); i++) {
            p = pointArray[i];
            Point q = pointArray[i+1];
            int sx1 = sc(p.x);
            int sy1 = sc(p.y);
            int sx2 = sc(q.x);
            int sy2 = sc(q.y);
            g.drawLine(sx1, sy1, sx2, sy2);
        }
        g.setColor(Color.blue);
        
        for(int i = 0; i < pointArray.length; i++) {
            p = pointArray[i];
            int sx = sc(p.x);
            int sy = sc(p.y);
            g.drawOval(sx-2,sy-2,4,4);
        }
    }
}
